@@ -272,6 +272,8 @@ class ShipmentDrop(Workflow, ModelSQL, ModelView):
         cls._error_messages.update({
                 'reset_move': ('You cannot reset to draft move "%s" which was '
                     'generated by a sale or a purchase.'),
+                'delete_cancel': ('Drop Shipment "%(shipment)s" must be '
+                    'cancelled before deletion.'),
                 })
 
     @staticmethod
@@ -386,14 +388,30 @@ class ShipmentDrop(Workflow, ModelSQL, ModelView):
         default['moves'] = None
         return super(ShipmentDrop, cls).copy(shipments, default=default)
 
+    @classmethod
+    def delete(cls, shipments):
+        pool = Pool()
+        Move = pool.get('stock.move')
+
+        cls.cancel(shipments)
+        for shipment in shipments:
+            if shipment.state != 'cancel':
+                cls.raise_user_error('delete_cancel', {
+                        'shipment': shipment.rec_name,
+                        })
+        Move.delete([m for s in shipments for m in s.supplier_moves])
+        super(ShipmentDrop, cls).delete(shipments)
+
     @classmethod
     @ModelView.button
     @Workflow.transition('cancel')
     def cancel(cls, shipments):
         Move = Pool().get('stock.move')
         Move.cancel([m for s in shipments for m in s.supplier_moves])
-        Move.write([m for s in shipments for m in s.customer_moves],
-            {'shipment': None})
+        Move.cancel([m for s in shipments for m in s.customer_moves
+                if s.state == 'shipped'])
+        Move.write([m for s in shipments for m in s.customer_moves
+                if s.state != 'shipped'], {'shipment': None})
 
     @classmethod
     @ModelView.button
@@ -538,7 +556,8 @@ class Move:
     @classmethod
     def search_customer_drop(cls, name, clause):
         return ['OR',
-            ('origin.sale.party',) + tuple(clause[1:]) + ('sale.line',),
-            (('origin.purchase.customer',) + tuple(clause[1:])
-                + ('purchase.line',)),
+            ('origin.sale.party' + clause[0].lstrip(name),)
+            + tuple(clause[1:3]) + ('sale.line',) + tuple(clause[3:]),
+            ('origin.purchase.customer' + clause[0].lstrip(name),)
+            + tuple(clause[1:3]) + ('purchase.line',) + tuple(clause[3:]),
             ]
